@@ -7,7 +7,7 @@ use Number::Phone::UK::Data;
 
 use base 'Number::Phone';
 
-our $VERSION = 1.556;
+our $VERSION = 1.6;
 
 my $cache = {};
 
@@ -17,7 +17,7 @@ Number::Phone::UK - UK-specific methods for Number::Phone
 
 =head1 SYNOPSIS
 
-    use Number::Phone::UK;
+    use Number::Phone;
 
     $daves_phone = Number::Phone->new('+44 1234 567890');
 
@@ -29,7 +29,7 @@ sub new {
     die("No number given to ".__PACKAGE__."->new()\n") unless($number);
 
     if(is_valid($number)) {
-        return bless(\$number, $class);
+        return bless(\$number, $class->_get_class(_clean_number($number)));
     } else { return undef; }
 }
 
@@ -47,6 +47,20 @@ true for any of the following methods will also be valid.
 
 =cut
 
+sub _get_class {
+  my $class = shift;
+  my $number = shift;
+  foreach my $prefix (_retards($number)) {
+    if(exists($Number::Phone::UK::Data::db->{subclass}->{$prefix})) {
+      my $subclass = join('::', $class, $Number::Phone::UK::Data::db->{subclass}->{$prefix});
+      eval "use $subclass";
+      die($@) if($@);
+      return $subclass;
+    }
+  }
+  return $class;
+}
+
 sub _clean_number {
     my $clean = shift;
     $clean =~ s/[^0-9+]//g;               # strip non-digits/plusses
@@ -63,8 +77,9 @@ sub _retards {
 sub is_valid {
     my $number = shift;
 
-    # if called as an object method, it *must* be valid otherwise the
+    # If called as an object method, it *must* be valid otherwise the
     # object would never have been instantiated.
+    # If called as a subroutine, that's the constructor doing its thang.
     return 1 if(blessed($number) && $number->isa(__PACKAGE__));
 
     # otherwise we have to validate
@@ -121,6 +136,8 @@ foreach my $is (qw(
     no strict 'refs';
     *{__PACKAGE__."::is_$is"} = sub {
         my $self = shift;
+        warn("DEPRECATION: ".__PACKAGE__."->is_$is should only be called as an object method\n")
+          unless(blessed($self));
         $self = shift if($self eq __PACKAGE__);
         $self = __PACKAGE__->new($self)
             unless(blessed($self) && $self->isa(__PACKAGE__));
@@ -152,6 +169,8 @@ foreach my $method (qw(operator areacode areaname subscriber)) {
     no strict 'refs';
     *{__PACKAGE__."::$method"} = sub {
         my $self = shift;
+        warn("DEPRECATION: ".__PACKAGE__."->$method should only be called as an object method\n")
+          unless(blessed($self));
         $self = (blessed($self) && $self->isa(__PACKAGE__)) ?
             $self :
             __PACKAGE__->new($self);
@@ -247,6 +266,8 @@ that number is assigned, if available.  Otherwise returns undef.
 
 sub location {
     my $self = shift;
+    warn("DEPRECATION: ".__PACKAGE__."->location should only be called as an object method\n")
+      unless(blessed($self));
     $self = (blessed($self) && $self->isa(__PACKAGE__)) ?
         $self :
         __PACKAGE__->new($self);
@@ -291,13 +312,18 @@ for the UK number (0208) 771-2924 it would return +44 20 87712924.
 
 sub format {
     my $self = shift;
+    warn("DEPRECATION: ".__PACKAGE__."->format should only be called as an object method\n")
+      unless(blessed($self));
     $self = (blessed($self) && $self->isa(__PACKAGE__)) ?
         $self :
         __PACKAGE__->new($self);
     return '+'.country_code().' '.(
-        $self->areacode()      ? $self->areacode().' '.$self->subscriber() :
-        !$self->is_allocated() ? substr(${$self}, 1 + length(country_code()))
-                               : $self->subscriber()
+        $self->areacode()      ? ($self->areacode().' '.(
+          length($self->subscriber()) == 7 ? substr($self->subscriber(), 0, 3).' '.substr($self->subscriber(), 3) :
+          length($self->subscriber()) == 8 ? substr($self->subscriber(), 0, 4).' '.substr($self->subscriber(), 4) :
+                                             $self->subscriber() )) : 
+        !$self->is_allocated() ? ( ${$self} =~ /^\+44/ ? substr(${$self}, 3) : substr(${$self}, 1)) :
+                                 $self->subscriber()
     );
 }
 
@@ -329,7 +355,7 @@ perl itself.
 
 David Cantrell E<lt>david@cantrell.org.ukE<gt>
 
-Copyright 2004 - 2007
+Copyright 2012
 
 =cut
 
